package com.shigongli.controller;

import com.shigongli.common.*;
import com.shigongli.entity.SysUser;
import com.shigongli.service.ISysUserService;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.result.WxMpOAuth2AccessToken;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import org.springframework.beans.factory.annotation.Autowired;
import com.shigongli.vo.LoginParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;


@Api(tags = "登入/登出")
@RestController
public class LoginController extends BaseController {

    @Autowired
    ISysUserService iSysUserService;

    @Autowired
    WxUtils wxUtils;

    /**
     * 公众号登录
     * @param code
     * @return
     * @throws Exception
     */
    @PostMapping("/mp/login")
    @ApiOperation(value="登录", notes = "登录", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean login(@ApiParam("登录参数") @RequestParam("code") String code) throws Exception {
        WxMpService mpService = wxUtils.getMpService();
        WxMpOAuth2AccessToken wxMpOAuth2AccessToken = mpService.oauth2getAccessToken(code);
        WxMpUser wxMpUser = mpService.oauth2getUserInfo(wxMpOAuth2AccessToken, null);

        SysUser sysUser = iSysUserService.getByOpenId(wxMpOAuth2AccessToken.getOpenId());
        if (null == sysUser) {
            sysUser = new SysUser();
            sysUser.setName(wxMpUser.getNickname());
            sysUser.setOpenid(wxMpUser.getOpenId());
            iSysUserService.save(sysUser);
        }

        if (StringUtils.isEmpty(sysUser.getPhone())) {
            return ResponseBean.error("请先联系管理员进行授权操作", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        // 生成 token
        Map<String, Object> claims = new HashMap<>();
        claims.put("userId", sysUser.getUserId());
        String jws = JWTUtils.encode(claims);
        sysUser.setToken(jws);

        return ResponseBean.success(sysUser);
    }
}
