package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.JWTUtils;
import com.shigongli.common.ResponseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.shigongli.service.ITaPersonService;
import com.shigongli.entity.TaPerson;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * <p>
    * 人员表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "人员表")
@RestController
@RequestMapping("/")
public class TaPersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPersonController.class);

    @Autowired
    public ITaPersonService iTaPersonService;

    @PostMapping("/ma/login")
    public ResponseBean login(String code) {
        // 用 code 去换 openid
        String openid = "";

        // 先查询人员是否存在
        TaPerson taPerson = iTaPersonService.getByOpenId(openid);

        // 如果人员不存在, 则新增
        if (null == taPerson) {
            taPerson = new TaPerson();
            taPerson.setOpenid(openid);
            iTaPersonService.save(taPerson);
//            taPerson = iTaPersonService.getById(taPerson.getPersonId());
        }

        // 生成 token
        Map<String, Object> claims = new HashMap<>();
        claims.put("personId", taPerson.getPersonId());
        String token = JWTUtils.encode(claims);
        taPerson.setToken(token);

        return ResponseBean.success(taPerson);
    }


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPerson",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                     @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                     HttpServletRequest request) throws Exception{

		    IPage<TaPerson> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPerson> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaPerson> result = iTaPersonService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taPerson",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taPersonAdd(@ApiParam("保存内容") @RequestBody TaPerson taPerson) throws Exception{

        if (iTaPersonService.save(taPerson)){
            return ResponseBean.success(taPerson);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPerson/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taPersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaPersonService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taPerson 实体对象
     * @return
     */
    @RequestMapping(value="/taPerson/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taPersonUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaPerson taPerson) throws Exception{

        if (iTaPersonService.updateById(taPerson)){
            return ResponseBean.success(iTaPersonService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPerson/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taPersonGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaPersonService.getById(id));
    }
}
